@@ -95,7 +95,7 @@ static void select_best_video_mode(int *best_w, int *best_h)
 	int i;
 	int dratio;
 
-	dratio = 100*display_w/display_h;
+	dratio = 1000*display_w/display_h;
 	wanted_mode.w = display_w;
 	wanted_mode.h = display_h;
 
@@ -118,7 +118,7 @@ static void select_best_video_mode(int *best_w, int *best_h)
 
 		/* select lowest mode with same ratio as display */
 		for(i=0;modes[i];++i)
-			if (100*modes[i]->w/modes[i]->h == dratio) {
+			if (1000*modes[i]->w/modes[i]->h == dratio) {
 				if (modes[i]->h < wanted_mode.h)
 					wanted_mode = *modes[i];
 			}
@@ -190,8 +190,8 @@ static void set_video_mode()
 	vsurf = SDL_GetVideoSurface();
 	screen = SDL_CreateRGBSurface( SDL_SWSURFACE, 640, 480,
 			vsurf->format->BitsPerPixel,
-			vsurf->format->Rmask, vsurf->format->Bmask,
-			vsurf->format->Gmask, vsurf->format->Amask );
+			vsurf->format->Rmask, vsurf->format->Gmask,
+			vsurf->format->Bmask, vsurf->format->Amask );
 
 }
 
@@ -271,8 +271,8 @@ static void fade_screen( int type, int time )
 	buffer = SDL_CreateRGBSurface( 
 			SDL_SWSURFACE, screen->w, screen->h, 
 			screen->format->BitsPerPixel,
-			screen->format->Rmask, screen->format->Bmask,
-			screen->format->Gmask, screen->format->Amask );
+			screen->format->Rmask, screen->format->Gmask,
+			screen->format->Bmask, screen->format->Amask );
 	if ( buffer == 0 ) return;
 	SDL_BlitSurface( screen, 0, buffer, 0 );
 
@@ -349,7 +349,7 @@ static void draw_score()
 static void draw_time( int ms )
 {
 	static int old_secs = 0;
-	char str[8];
+	char str[16];
 	int secs = game_end - time(0);
 	
 	/* blink timer when time is running out in such a way
@@ -366,7 +366,7 @@ static void draw_time( int ms )
 	}
 	
 	if ( !timer_visible ) return;
-	snprintf( str, 8, "%i:%02i", secs/60, secs%60 ); str[7] = 0;
+	snprintf( str, 16, "%d:%02d", secs/60, secs%60 ); str[15] = 0;
 	SDL_WriteTextRight( ft_main, screen, 630, 10, str );
 }
 
@@ -757,7 +757,7 @@ int main( int argc, char **argv )
   const SDL_VideoInfo* info;
 
   printf( "BARRAGE v%s\n", VERSION );
-  printf( "Copyright 2003-2019 Michael Speck (http://lgames.sf.net)\n" );
+  printf( "Copyright 2003-2022 Michael Speck (http://lgames.sf.net)\n" );
   printf( "Released under GNU GPL\n---\n" );
 
   while ( ( c = getopt( argc, argv, "d:wsr:" ) ) != -1 )
